@@ -1,6 +1,6 @@
 var group__spa__dict =
 [
-    [ "dict.h", "utils_2dict_8h.html", null ],
+    [ "utils/dict.h", "utils_2dict_8h.html", null ],
     [ "spa_dict_item", "structspa__dict__item.html", [
       [ "key", "structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a", null ],
       [ "value", "structspa__dict__item.html#af08479e3ff870039be002b436a02457d", null ]
