@@ -1,5 +1,13 @@
 var NAVTREEINDEX5 =
 {
+"group__pw__session__manager.html#ga2e7a34daf8b8253ed9bffd78cdca8e7f":[10,7,4,89],
+"group__pw__session__manager.html#ga2f3475c7169a333132c7adf5ab5f818b":[10,7,4,105],
+"group__pw__session__manager.html#ga3126b0d16a1105a0075ffdc1b8d25fc4":[10,7,4,64],
+"group__pw__session__manager.html#ga31cff50a1b1c9652e16d4666b39f890a":[10,7,4,140],
+"group__pw__session__manager.html#ga34caaf07827cde7ac74e35a2c23c4dde":[10,7,4,142],
+"group__pw__session__manager.html#ga36c9ea5feb170e0ed71922b1b5d92cc3":[10,7,4,120],
+"group__pw__session__manager.html#ga39a3486c87f2ceae5fc7f1ccb3be65b8":[10,7,4,162],
+"group__pw__session__manager.html#ga3a177f6b1893ad6969720adcf7683868":[10,7,4,157],
 "group__pw__session__manager.html#ga3e4945a8ef7615d8e4b574209890a68b":[10,7,4,148],
 "group__pw__session__manager.html#ga3e540bd1f6f3ba78a5642862792be5c0":[10,7,4,85],
 "group__pw__session__manager.html#ga441321996ff6d23a5b17ec8bfae05b89":[10,7,4,171],
@@ -199,11 +207,11 @@ var NAVTREEINDEX5 =
 "group__pw__thread__loop.html#ga7cc82c62d85014248b66db0947e4f087":[10,5,15,18],
 "group__pw__thread__loop.html#ga856c3aec5718bceb92d6169c42062186":[10,5,15,10],
 "group__pw__thread__loop.html#gaa7996893e812e9eec61f786d1c691c54":[10,5,15,11],
-"group__pw__thread__loop.html#gab79bf196bb3db3b8182285c2f7d6d545":[10,5,15,16],
 "group__pw__thread__loop.html#gabdc2e68dfd070fe58770143f184fc026":[10,5,15,5],
 "group__pw__thread__loop.html#gacb9c26a513d752803fd272a4ea2bc891":[10,5,15,19],
 "group__pw__thread__loop.html#gad05bec2017f1081bccec2f0def34e9d3":[10,5,15,4],
 "group__pw__thread__loop.html#gae97c812b1fa7696909d3e4419e4e079e":[10,5,15,13],
+"group__pw__thread__loop.html#gaf191188f2dc2ddfbc1e9bb84764709eb":[10,5,15,16],
 "group__pw__thread__loop.html#gaf9bc8dd348d05b095139f5a55ac5a4b0":[10,5,15,17],
 "group__pw__type.html":[10,4,15],
 "group__pw__type.html#ga0cf80ee6ff44b9e1a1309cd59775f91d":[10,4,15,3],
@@ -214,16 +222,17 @@ var NAVTREEINDEX5 =
 "group__pw__type.html#gac0ee38218f80b11ad0586f7c30a1fc2f":[10,4,15,2],
 "group__pw__type.html#gga06fc87d81c62e9abb8790b6e5713c55ba3b264f61faadc9037f84e239b177ff0b":[10,4,15,5,0],
 "group__pw__utils.html":[10,6,8],
-"group__pw__utils.html#ga40eebfe720dbba23dbc86347dd95ba0b":[10,6,8,2],
-"group__pw__utils.html#ga80e0ca15ccef3f20ef9524a26d8c2b45":[10,6,8,6],
-"group__pw__utils.html#ga86777dfdd21dbb21a2c74470aad019a4":[10,6,8,3],
+"group__pw__utils.html#ga40eebfe720dbba23dbc86347dd95ba0b":[10,6,8,3],
+"group__pw__utils.html#ga80e0ca15ccef3f20ef9524a26d8c2b45":[10,6,8,7],
+"group__pw__utils.html#ga86777dfdd21dbb21a2c74470aad019a4":[10,6,8,4],
 "group__pw__utils.html#ga8869815cdd42998571019730afd248ff":[10,6,8,0],
 "group__pw__utils.html#ga8927bee5a1c2d50bf44dffc697b24840":[10,6,8,1],
-"group__pw__utils.html#ga9349b2873f42849a409d3526fd874ecc":[10,6,8,9],
-"group__pw__utils.html#gaada7b1ede9468dc38e00907c52c2969b":[10,6,8,5],
-"group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9":[10,6,8,7],
-"group__pw__utils.html#gac9f252f07455653aebd285fc9e05feee":[10,6,8,8],
-"group__pw__utils.html#gacdc181bb9d9a0be73f19ad2745630399":[10,6,8,4],
+"group__pw__utils.html#ga9349b2873f42849a409d3526fd874ecc":[10,6,8,10],
+"group__pw__utils.html#ga97004c44df1cac3ac75257c40ff8ce58":[10,6,8,2],
+"group__pw__utils.html#gaada7b1ede9468dc38e00907c52c2969b":[10,6,8,6],
+"group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9":[10,6,8,8],
+"group__pw__utils.html#gac9f252f07455653aebd285fc9e05feee":[10,6,8,9],
+"group__pw__utils.html#gacdc181bb9d9a0be73f19ad2745630399":[10,6,8,5],
 "group__pw__work__queue.html":[10,5,16],
 "group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db":[10,5,16,5],
 "group__pw__work__queue.html#ga528c2be5bb8ef21bdbe8bfa44485f8bb":[10,5,16,2],
@@ -240,14 +249,5 @@ var NAVTREEINDEX5 =
 "group__pwtest.html#ga1536e136ab274b09533862681ddf8075":[10,2,29],
 "group__pwtest.html#ga1f365422ab4403a3f3799b3667e01ff4":[10,2,14],
 "group__pwtest.html#ga235878471a0cc9e96ec3a167cd154f53":[10,2,26],
-"group__pwtest.html#ga288f936c9cb1fea769e8fcf616650ba5":[10,2,5],
-"group__pwtest.html#ga2c915fce91d56c38b5f5a3c4e58c43b2":[10,2,24],
-"group__pwtest.html#ga30b74c4eb3256e1c351bb036cb338990":[10,2,17],
-"group__pwtest.html#ga31aadf049c2da1eaa5735511d1cafef6":[10,2,37],
-"group__pwtest.html#ga3abfb07ed321c803757a34edcf56ef73":[10,2,48],
-"group__pwtest.html#ga45b76d40140c645308b3759dfc351ada":[10,2,20],
-"group__pwtest.html#ga51c9bca0ae9864feb3aa5ec79d7e1e71":[10,2,15],
-"group__pwtest.html#ga54e354518bf9333c3c92c8556ad0c328":[10,2,32],
-"group__pwtest.html#ga5729ceef65ee401eb01e0a5a882eb3bc":[10,2,34],
-"group__pwtest.html#ga5a5ba20824f92f66f86a8d1656db0ea5":[10,2,51]
+"group__pwtest.html#ga288f936c9cb1fea769e8fcf616650ba5":[10,2,5]
 };
